pub fn contains_point(
shape: &ConvexShape,
point: Point3,
tolerance: Scalar,
) -> boolExpand description
Whether a point lies inside or on a convex shape.
pub fn contains_point(
shape: &ConvexShape,
point: Point3,
tolerance: Scalar,
) -> boolWhether a point lies inside or on a convex shape.