pub struct Contact {
pub axis: Vec3,
pub distance: Scalar,
}Expand description
The axis along which two shapes are furthest apart.
Fields
axis: Vec3Unit direction of least overlap, pointing from a towards b.
distance: ScalarGap along axis.